==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Home',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles by this author',
	'articles_populaires' => 'Most popular articles',
	'articles_rubrique' => 'Articles in this section',
	'aucun_article' => 'No articles here',
	'aucun_auteur' => 'No authors here',
	'aucun_site' => 'No links here',
	'aucune_breve' => 'No news items here',
	'aucune_rubrique' => 'No sections here',
	'auteur' => 'Author',
	'autres' => 'Others',
	'autres_breves' => 'Other news',
	'autres_groupes_mots_clefs' => 'Other groups of keywords',
	'autres_sites' => 'Other websites',

	// B
	'bonjour' => 'Hello',

	// C
	'commenter_site' => 'Comment on this site',
	'contact' => 'Contact',
	'copie_document_impossible' => 'Impossible to copy this document',

	// D
	'date' => 'Date',
	'dernier_ajout' => 'Latest update',
	'dernieres_breves' => 'Latest news',
	'derniers_articles' => 'Latest articles',
	'derniers_commentaires' => 'Latest comments',
	'derniers_messages_forum' => 'Latest forum posts',

	// E
	'edition_mode_texte' => 'Text mode only',
	'en_reponse' => 'Replying to:',
	'en_resume' => 'Summary',
	'envoyer_message' => 'Send a message',
	'espace_prive' => 'Private area',

	// F
	'formats_acceptes' => 'Valid formats: @formats@.',

	// H
	'hierarchie_site' => 'Site map',

	// J
	'jours' => 'days',

	// L
	'lien_connecter' => 'Log in',

	// M
	'meme_auteur' => 'By the same author',
	'meme_rubrique' => 'Also in this section',
	'memes_auteurs' => 'By the same authors',
	'message' => 'Message',
	'messages_forum' => 'Forum posts',
	'messages_recents' => 'Most recent forum posts',
	'mots_clef' => 'Keyword',
	'mots_clefs' => 'Keywords',
	'mots_clefs_meme_groupe' => 'Other keywords in this group',

	// N
	'navigation' => 'Browsing',
	'nom' => 'Name',
	'nouveautes' => 'What’s new',
	'nouveautes_web' => 'What’s new on the Web',
	'nouveaux_articles' => 'New articles',
	'nouvelles_breves' => 'Latest news items',

	// P
	'page_precedente' => 'previous page',
	'page_suivante' => 'next page',
	'par_auteur' => 'by ',
	'participer_site' => 'You can take active part in this website and write your own articles by signing up here. You will receive an email with your account information for the private area of the site.',
	'plan_site' => 'Site Map',
	'popularite' => 'Popularity',
	'poster_message' => 'Post a message',
	'proposer_site' => 'You can suggest a website for inclusion in this section:',

	// R
	'repondre_article' => 'Comment on this article',
	'repondre_breve' => 'Comment on this news item',
	'resultats_recherche' => 'Search results',
	'retour_debut_forums' => 'Back to forum top',
	'rss_abonnement' => 'Simply copy the following URL into your aggregator:',
	'rss_abonnement_titre' => 'Subscribe',
	'rss_abonnement_titre_page' => 'Subscribe to',
	'rss_explication' => 'An RSS thread collects information about a site’s update. It delivers the content of the tickets or the comments or an extract of them, as well as a link to the full versions et some other information. This thread is to be read by an RSS aggregator.',
	'rss_explication_titre' => 'What is an RSS feed?',
	'rubrique' => 'Section',
	'rubriques' => 'Sections',

	// S
	'signatures_petition' => 'Signatures',
	'site_realise_avec_spip' => 'Site powered by SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Subsections',
	'spam' => 'Spam',
	'suite' => 'continue',
	'sur_web' => 'Around the Web',
	'syndiquer_rubrique' => 'Subscribe to this section',
	'syndiquer_site' => 'Subscribe to the whole site',

	// T
	'texte_lettre_information' => 'Here is the site newsletter',
	'texte_lettre_information_2' => 'This site contains news items published since',

	// V
	'ver_imprimer' => 'Printable version',
	'voir_en_ligne' => 'View online',
	'voir_squelette' => 'show the template of this page'
);

==> spip_4.4.8+dfsg.orig.tar.xz: ecrire/lang/public_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public_?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Home',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles by this author',
	'articles_populaires' => 'Most popular articles',
	'articles_rubrique' => 'Articles in this section',
	'aucun_article' => 'No articles here',
	'aucun_auteur' => 'No authors here',
	'aucun_site' => 'No links here',
	'aucune_breve' => 'No news items here',
	'aucune_rubrique' => 'No sections here',
	'auteur' => 'Author',
	'autres' => 'Others',
	'autres_breves' => 'Other news',
	'autres_groupes_mots_clefs' => 'Other groups of keywords',
	'autres_sites' => 'Other websites',

	// B
	'bonjour' => 'Hello',

	// C
	'commenter_site' => 'Comment on this site',
	'contact' => 'Contact',
	'copie_document_impossible' => 'Impossible to copy this document',

	// D
	'date' => 'Date',
	'dernier_ajout' => 'Latest update',
	'dernieres_breves' => 'Latest news',
	'derniers_articles' => 'Latest articles',
	'derniers_commentaires' => 'Latest comments',
	'derniers_messages_forum' => 'Latest forum posts',

	// E
	'edition_mode_texte' => 'Text mode only',
	'en_reponse' => 'Replying to:',
	'en_resume' => 'Summary',
	'envoyer_message' => 'Send a message',
	'espace_prive' => 'Back-office',

	// F
	'formats_acceptes' => 'Valid formats: @formats@.',

	// H
	'hierarchie_site' => 'Site map',

	// J
	'jours' => 'days',

	// L
	'lien_connecter' => 'Log in',

	// M
	'meme_auteur' => 'By the same author',
	'meme_rubrique' => 'Also in this section',
	'memes_auteurs' => 'By the same authors',
	'message' => 'Message',
	'messages_forum' => 'Forum posts',
	'messages_recents' => 'Most recent forum posts',
	'mots_clef' => 'Keyword',
	'mots_clefs' => 'Keywords',
	'mots_clefs_meme_groupe' => 'Other keywords in this group',

	// N
	'navigation' => 'Browsing',
	'nom' => 'Name',
	'nouveautes' => 'What’s new',
	'nouveautes_web' => 'What’s new on the Web',
	'nouveaux_articles' => 'New articles',
	'nouvelles_breves' => 'Latest news items',

	// P
	'page_precedente' => 'previous page',
	'page_suivante' => 'next page',
	'par_auteur' => 'by ',
	'participer_site' => 'You can take active part in this website and write your own articles by signing up here. You will receive an email with your account information for the back-office of the site.',
	'plan_site' => 'Site Map',
	'popularite' => 'Popularity',
	'poster_message' => 'Post a message',
	'proposer_site' => 'You can suggest a website for inclusion in this section:',

	// R
	'repondre_article' => 'Comment on this article',
	'repondre_breve' => 'Comment on this news item',
	'resultats_recherche' => 'Search results',
	'retour_debut_forums' => 'Back to forum top',
	'rss_abonnement' => 'Simply copy the following URL into your aggregator:',
	'rss_abonnement_titre' => 'Subscribe',
	'rss_abonnement_titre_page' => 'Subscribe to',
	'rss_explication' => 'An RSS thread collects information about a site’s update. It delivers the content of the tickets or the comments or an extract of them, as well as a link to the full versions et some other information. This thread is to be read by an RSS aggregator.',
	'rss_explication_titre' => 'What is an RSS feed?',
	'rubrique' => 'Section',
	'rubriques' => 'Sections',

	// S
	'signatures_petition' => 'Signatures',
	'site_realise_avec_spip' => 'Site powered by SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Subsections',
	'spam' => 'Spam',
	'suite' => 'continue',
	'sur_web' => 'Around the Web',
	'syndiquer_rubrique' => 'Subscribe to this section',
	'syndiquer_site' => 'Subscribe to the whole site',

	// T
	'texte_lettre_information' => 'Here is the site newsletter',
	'texte_lettre_information_2' => 'This site contains news items published since',

	// V
	'ver_imprimer' => 'Printable version',
	'voir_en_ligne' => 'View online',
	'voir_squelette' => 'show the template of this page',
];
